'use strict';

module.exports = {
    formatter: require.resolve('./format'),

    rules: {
        'body-leading-blank': [2, 'always'],                            // body begins with blank line
        'body-max-length': [0, 'always', 72],                           // body has [value] or less characters
        'body-max-line-length': [0, 'always', 3],                       // body lines has [value] or less characters
        'body-min-length': [0, 'always', 0],                            // body has [value] or more characters

        'footer-leading-blank': [2, 'always'],                          // footer begins with blank line
        'footer-max-length': [0, 'always', 72],                         // footer has [value] or less characters
        'footer-max-line-length': [0, 'always', 3],                     // footer lines has [value] or less characters
        'footer-min-length': [0, 'always', 0],                          // footer has [value] or more characters

        'header-case': [                                                // header is in case [value]
            0,
            'always',
            [
                'lower-case',   // default
                'upper-case',   // UPPERCASE
                'camel-case',   // camelCase
                'kebab-case',   // kebab-case
                'pascal-case',  // PascalCase
                'sentence-case', // Sentence case
                'snake-case',   // snake_case
                'start-case',   // Start Case
            ],
        ],
        'header-full-stop': [2, 'never', '.'],                          // header ends with [value]
        'header-max-length': [0, 'always', 72],                         // header has [value] or less characters
        'header-min-length': [0, 'always', 0],                          // header has [value] or more characters
        'references-empty': [0, 'never'],                               // references has at least one entry

        'scope-enum': [0, 'always', []],                                // scope is found in value
        'scope-case': [                                                 // scope is in case [value]
            2,
            'always',
            [
                'lower-case',
            ],
        ],
        'scope-empty': [0, 'never'],                                   // scope is empty
        'scope-max-length': [0, 'always', 12],                         // scope has [value] or less characters
        'scope-min-length': [0, 'always', 2],                          // scope has [value] or more characters

        'subject-case': [                                              // subject is in case [value]
            0,
            'always',
            [
                'lower-case',   // default
                'upper-case',   // UPPERCASE
                'camel-case',   // camelCase
                'kebab-case',   // kebab-case
                'pascal-case',  // PascalCase
                'sentence-case', // Sentence case
                'snake-case',   // snake_case
                'start-case',   // Start Case
            ],
        ],
        'subject-empty': [2, 'never'],                                  // subject is empty
        'subject-full-stop': [2, 'never', '.'],                        // subject ends with [value]
        'subject-max-length': [0, 'always', 56],                        // subject has [value] or less characters
        'subject-min-length': [0, 'always', 3],                         // subject has [value] or more characters

        'type-enum': [                                                  // type is found in value
            2,
            'always',
            [
                'init',
                'feat',
                'fix',
                'style',
                'chore',
                'build',
                'test',
                'docs',
                'lang',
                'revert',
                'refactor',
                'example',
                'release',
            ],
        ],
        'type-case': [                                                   // type is in case [value]
            2,
            'always',
            [
                'lower-case',   // default
            ],
        ],
        'type-empty': [2, 'never'],                                     // type is empty
        'type-max-length': [0, 'always', 8],                            // type has [value] or less characters
        'type-min-length': [0, 'always', 0],                            // type has [value] or more characters

        'signed-off-by': [0, 'always', ''],                             // message has [value]
    },
};
